===================
Layered Config Tree
===================

Layered Config Tree is a configuration structure that supports cascading layers.

**Layered Config Tree requires Python 3.8-3.11 to run**

You can build ``layered_config_tree`` from from source with

  ``> git clone https://github.com/ihmeuw/layered_config_tree.git``

  ``> cd layered_config_tree``

  ``> conda create -n ENVIRONMENT_NAME python=3.11``

  ``> pip install .``

This will make the ``layered_config_tree`` library available to python.
